@@ -7,4 +7,6 @@ urlpatterns = patterns('django_rq.views',
         name='rq_job_detail'),
     url(r'^queues/(?P<queue_index>[\d]+)/(?P<job_id>[-\w]+)/delete/$',
         'delete_job', name='rq_delete_job'),
+    url(r'^queues/(?P<queue_index>[\d]+)/(?P<job_id>[-\w]+)/requeue/$',
+        'requeue_job_view', name='rq_requeue_job'),
 )
